/*
 * modified from ApplySignal.ino
 * 2018 WLWilliams
 * 
 * modified for two AD9833s Adjustable MTS 2020
 *
 * This sketch demonstrates the basic use of the AD9833 DDS module library.
 * Using the ApplySignal to generate and/or change the signal.
 * 
 * This program is free software: you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version. 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of
 * the GNU General Public License along with this program.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * This example code is in the public domain.
 * 
 * Library code found at: https://github.com/Billwilliams1952/AD9833-Library-Arduino
 * 
 */

#include <AD9833.h>     // Include the library

#define FNC_PINL 8       // Left channel
#define FNC_PINR 9       // Right channel

float LFreq;
float RFreq;
float LActual, RActual;

#define FLUSH_SERIAL_INPUT  if ( serialEventRun ) serialEventRun(); \
                            do { Serial.read(); delay(100); } while ( Serial.available() > 0 );

//--------------- Create an AD9833 object ---------------- 
// Note, SCK and MOSI must be connected to CLK and DAT pins on the AD9833 for SPI
AD9833 genL(FNC_PINL);       // Defaults to 25MHz internal reference frequency
AD9833 genR(FNC_PINR);       // Defaults to 25MHz internal reference frequency

// Prototype
void DisplayMenu();

void setup() {
  // This MUST be the first command after declaring the AD9833 object
  genL.Begin();              
  genR.Begin();              
  Serial.begin(115200);
  while(!Serial); // Comment out if battery powered
  
  DisplayMenu();
  
}

void loop() {
  if ( Serial.available() ) {
      char ch = Serial.read();
      FLUSH_SERIAL_INPUT
	    DisplayMenu();
      
     switch ( toupper(ch)) {
          case 'L':
              FLUSH_SERIAL_INPUT
              Serial.println("Enter frequency");
              while ( !Serial.available() ) //Wait 
              LFreq = Serial.parseFloat();
              genL.SetFrequency(REG0,LFreq);
              LActual = genL.GetActualProgrammedFrequency(REG0);
              Serial.print("Requested :");
              Serial.print(LFreq,3); 
              Serial.print("   Actual :");
              Serial.println(LActual,3); 
              genL.EnableOutput(true);   // Turn ON the output - it defaults to OFF
              break;  
          case 'R':
              FLUSH_SERIAL_INPUT
              Serial.println("Enter frequency");
              while ( !Serial.available() ) //Wait 
              RFreq = Serial.parseFloat();
              genR.SetFrequency(REG0,RFreq);
              RActual = genR.GetActualProgrammedFrequency(REG0);
              Serial.print("Requested :");
              Serial.print(RFreq,3); 
              Serial.print("   Actual :");
              Serial.println(RActual,3); 
              genR.EnableOutput(true);   // Turn ON the output - it defaults to OFF
              break;  
          default:
              Serial.println(F("*** Invalid command ***"));
              break;  
     }                  
	}
}

void DisplayMenu(){
  Serial.println();
  Serial.println("***************DISPLAY MENU****************");
  Serial.print("LFreq");
  Serial.print("\t \t");
  Serial.print("LActual");
  Serial.print("\t \t");
  Serial.print("RFreq");
  Serial.print("\t \t");
  Serial.print("RActual");
  Serial.print("\t \t");
  Serial.println("Difference");
  
  Serial.print(LFreq,2);
  Serial.print("\t \t");
  Serial.print(LActual,2);
  Serial.print("\t \t");
  Serial.print(RFreq,2);
  Serial.print("\t \t");
  Serial.print(RActual,2);
  Serial.print("\t \t");
  Serial.println(abs(LActual-RActual),2);
  Serial.println();
  
  Serial.println(" To change frequency, enter 'l' or 'r'");
}
